"use strict";
require('rxjs/add/operator/map');
require('rxjs/add/operator/catch');
var Observable_1 = require("rxjs/Observable");
var core_1 = require('@angular/core');
var http_1 = require('@angular/http');
var interfaces_1 = require('./interfaces');
var FontPickerService = (function () {
    function FontPickerService(config, http) {
        this.config = config;
        this.http = http;
        this.apiKey = "";
        this.baseUrl = 'https://www.googleapis.com/webfonts/v1/webfonts';
        this.apiKey = config.apiKey;
    }
    /*
      Return all fonts avaliable from google fonts, may have sort parameter:
      date || alpha || style || trending || popularity
    */
    FontPickerService.prototype.getAllFonts = function (sort) {
        var requestUrl = this.baseUrl + '?key=' + this.apiKey;
        if (sort) {
            requestUrl = requestUrl.concat('&sort=' + sort);
        }
        return this.http.get(requestUrl)
            .map(function (res) { return res.json(); })
            .catch(this.handleHttpError);
    };
    /*
      Return observable of the requested font
    */
    FontPickerService.prototype.getRequestedFont = function (family) {
        var requestUrl = 'https://fonts.googleapis.com/css?family=' + family;
        return this.http.get(requestUrl)
            .map(function (res) { return res.json(); })
            .catch(this.handleHttpError);
    };
    /*
      Handler for possible http request errors
    */
    FontPickerService.prototype.handleHttpError = function (error) {
        var errMsg = (error.message) ? error.message :
            error.status ? error.status + " - " + error.statusText : 'Server error';
        return Observable_1.Observable.throw(errMsg);
    };
    FontPickerService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    FontPickerService.ctorParameters = function () { return [
        { type: interfaces_1.FontPickerConfig, decorators: [{ type: core_1.Inject, args: [interfaces_1.FontPickerConfig,] },] },
        { type: http_1.Http, },
    ]; };
    return FontPickerService;
}());
exports.FontPickerService = FontPickerService;
//# sourceMappingURL=font-picker.service.js.map